@@ -1,27 +1,36 @@
 // Copyright The OpenTelemetry Authors
 // SPDX-License-Identifier: Apache-2.0
 
+#include <prometheus/client_metric.h>
+#include <prometheus/metric_family.h>
+#include <prometheus/metric_type.h>
 #include <algorithm>
+#include <chrono>
+#include <cstddef>
+#include <cstdint>
+#include <functional>
 #include <limits>
+#include <map>
 #include <regex>
 #include <sstream>
 #include <string>
+#include <type_traits>
 #include <unordered_map>
-#include <unordered_set>
 #include <utility>
 #include <vector>
 
-#include "prometheus/metric_family.h"
-#include "prometheus/metric_type.h"
-
-#include "opentelemetry/common/macros.h"
+#include "opentelemetry/common/timestamp.h"
 #include "opentelemetry/exporters/prometheus/exporter_utils.h"
-#include "opentelemetry/sdk/metrics/export/metric_producer.h"
-#include "opentelemetry/sdk/resource/resource.h"
-#include "opentelemetry/sdk/resource/semantic_conventions.h"
-#include "opentelemetry/trace/semantic_conventions.h"
-
+#include "opentelemetry/nostd/variant.h"
+#include "opentelemetry/sdk/common/attribute_utils.h"
 #include "opentelemetry/sdk/common/global_log_handler.h"
+#include "opentelemetry/sdk/instrumentationscope/instrumentation_scope.h"
+#include "opentelemetry/sdk/metrics/data/metric_data.h"
+#include "opentelemetry/sdk/metrics/data/point_data.h"
+#include "opentelemetry/sdk/metrics/export/metric_producer.h"
+#include "opentelemetry/sdk/metrics/instruments.h"
+#include "opentelemetry/sdk/resource/resource.h"
+#include "opentelemetry/version.h"
 
 namespace prometheus_client = ::prometheus;
 namespace metric_sdk        = opentelemetry::sdk::metrics;
@@ -102,13 +111,15 @@ std::string SanitizeLabel(std::string label_key)
  * Helper function to convert OpenTelemetry metrics data collection
  * to Prometheus metrics data collection
  *
- * @param records a collection of metrics in OpenTelemetry
+ * @param data a collection of metrics in OpenTelemetry
  * @return a collection of translated metrics that is acceptable by Prometheus
  */
 std::vector<prometheus_client::MetricFamily> PrometheusExporterUtils::TranslateToPrometheus(
     const sdk::metrics::ResourceMetrics &data,
     bool populate_target_info,
-    bool without_otel_scope)
+    bool without_otel_scope,
+    bool without_units,
+    bool without_type_suffix)
 {
 
   // initialize output vector
@@ -150,7 +161,8 @@ std::vector<prometheus_client::MetricFamily> PrometheusExporterUtils::TranslateT
       }
       const prometheus_client::MetricType type = TranslateType(kind, is_monotonic);
       metric_family.name = MapToPrometheusName(metric_data.instrument_descriptor.name_,
-                                               metric_data.instrument_descriptor.unit_, type);
+                                               metric_data.instrument_descriptor.unit_, type,
+                                               without_units, without_type_suffix);
       metric_family.type = type;
       const opentelemetry::sdk::instrumentationscope::InstrumentationScope *scope =
           without_otel_scope ? nullptr : instrumentation_info.scope_;
@@ -492,34 +504,43 @@ std::string PrometheusExporterUtils::CleanUpString(const std::string &str)
 std::string PrometheusExporterUtils::MapToPrometheusName(
     const std::string &name,
     const std::string &unit,
-    prometheus_client::MetricType prometheus_type)
+    prometheus_client::MetricType prometheus_type,
+    bool without_units,
+    bool without_type_suffix)
 {
-  auto sanitized_name                    = SanitizeNames(name);
-  std::string prometheus_equivalent_unit = GetEquivalentPrometheusUnit(unit);
-
-  // Append prometheus unit if not null or empty.
-  if (!prometheus_equivalent_unit.empty() &&
-      sanitized_name.find(prometheus_equivalent_unit) == std::string::npos)
+  auto sanitized_name = SanitizeNames(name);
+  // append unit suffixes
+  if (!without_units)
   {
-    sanitized_name += "_" + prometheus_equivalent_unit;
-  }
-
-  // Special case - counter
-  if (prometheus_type == prometheus_client::MetricType::Counter)
-  {
-    auto t_pos           = sanitized_name.rfind("_total");
-    bool ends_with_total = t_pos == sanitized_name.size() - 6;
-    if (!ends_with_total)
+    std::string prometheus_equivalent_unit = GetEquivalentPrometheusUnit(unit);
+    // Append prometheus unit if not null or empty.
+    if (!prometheus_equivalent_unit.empty() &&
+        sanitized_name.find(prometheus_equivalent_unit) == std::string::npos)
     {
-      sanitized_name += "_total";
+      sanitized_name += "_" + prometheus_equivalent_unit;
+    }
+    // Special case - gauge
+    if (unit == "1" && prometheus_type == prometheus_client::MetricType::Gauge &&
+        sanitized_name.find("ratio") == std::string::npos)
+    {
+      // this is replacing the unit name
+      sanitized_name += "_ratio";
     }
   }
 
-  // Special case - gauge
-  if (unit == "1" && prometheus_type == prometheus_client::MetricType::Gauge &&
-      sanitized_name.find("ratio") == std::string::npos)
+  // append type suffixes
+  if (!without_type_suffix)
   {
-    sanitized_name += "_ratio";
+    // Special case - counter
+    if (prometheus_type == prometheus_client::MetricType::Counter)
+    {
+      auto t_pos           = sanitized_name.rfind("_total");
+      bool ends_with_total = t_pos == sanitized_name.size() - 6;
+      if (!ends_with_total)
+      {
+        sanitized_name += "_total";
+      }
+    }
   }
 
   return CleanUpString(SanitizeNames(sanitized_name));
@@ -760,7 +781,7 @@ std::string PrometheusExporterUtils::AttributeValueToString(
  * Handle Counter.
  */
 template <typename T>
-void PrometheusExporterUtils::SetValue(std::vector<T> values,
+void PrometheusExporterUtils::SetValue(const std::vector<T> &values,
                                        prometheus_client::MetricType type,
                                        prometheus_client::ClientMetric *metric)
 {
@@ -798,7 +819,7 @@ void PrometheusExporterUtils::SetValue(std::vector<T> values,
  * Handle Histogram
  */
 template <typename T>
-void PrometheusExporterUtils::SetValue(std::vector<T> values,
+void PrometheusExporterUtils::SetValue(const std::vector<T> &values,
                                        const std::vector<double> &boundaries,
                                        const std::vector<uint64_t> &counts,
                                        prometheus_client::ClientMetric *metric)
